@@ -323,3 +323,61 @@ class OfficeRegistrator(Base):
 
     def __str__(self):
         return str(self.personnel)
+
+
+class Dean(Base):
+    """
+    Модель "Декан"
+    """
+    __tablename__ = 'univer_dekan'
+
+    # Идентификатор
+    id = Column('dekan_id', Integer, primary_key=True)
+
+    # Сотрудник
+    personnel_id = Column('personal_id', ForeignKey(
+        'univer_personal.personal_id'))
+    personnel = relationship('Personnel')
+
+    # Факультет
+    faculty_id = Column(ForeignKey('univer_faculty.faculty_id'))
+    faculty = relationship('Faculty')
+
+    # Дата начала
+    start_date = Column('dekan_start_date', DateTime)
+
+    # Дата окончания
+    end_date = Column('dekan_end_date', DateTime)
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<Dean {} (id={})>'.format(self, self.id)
+
+    def __str__(self):
+        return str(self.personnel)
+
+
+class TeacherChairLink(Base):
+    """
+    Модель отношение между Teacher (Преподаватель) и Chair (Кафедра)
+    """
+    __tablename__ = 'univer_teacher_chair_link'
+
+    # Преподаватель
+    teacher_id = Column(ForeignKey('univer_teacher.teacher_id'))
+    teacher = relationship('Teacher')
+
+    # Кафедра
+    chair_id = Column(ForeignKey('univer_chair.chair_id'))
+    chair = relationship('Chair')
+
+    # Ставка
+    rate = Column('stavka', Integer)
+
+    def __repr__(self):
+        return '<TeacherChairLink {} (id={})>'.format(self, self.id)
+
+    def __str__(self):
+        return f"{self.chair}: {self.teacher}"
